@@ -120,6 +120,12 @@ class Entity:
     def _get_computed_fields(cls):
         return [f for f in cls._get_meta_fields() if isinstance(f, ComputedField)]
 
+    @classmethod
+    def _get_computed_field(cls, matching_fn):
+        for field in cls._get_meta_fields():
+            if isinstance(field, ComputedField) and matching_fn(field):
+                return field
+
     @classmethod
     def get_all_model_fields(cls):
         result = {}
