@@ -7,6 +7,9 @@ def build_by_pk_resolver(model_class, registry):
     def by_pk_resolver(parent, info, **kwargs):
         queryset = entity_class.get_queryset(info.context).filter(**kwargs)
         artifacts = visit_query(registry, info)
-        return artifacts["queryset_optimizer"].optimize(queryset).get()
+        optimizer = artifacts.get("queryset_optimizer")
+        if not optimizer:
+            return queryset
+        return optimizer.optimize(queryset).get()
 
     return by_pk_resolver
