@@ -57,52 +57,53 @@ def update_queryset_based_on_arguments(queryset, args, take_slice=True):
 def filter_from_where_args(where_args, annotations, _and=True):
     combined_qs = []
     for key, value in iteritems(where_args):
+        anded_qs = []
         # Conjunction operations
         if key in ("_and", "_or"):
             joined = reduce(
                 lambda result, q: q & result if key == "_and" else q | result,
                 [filter_from_where_args(item, annotations) for item in value],
             )
-            combined_qs.append(joined)
+            anded_qs.append(joined)
 
         # Negation operation
         if key == "_not":
-            combined_qs.append(~filter_from_where_args(value, annotations))
+            anded_qs.append(~filter_from_where_args(value, annotations))
 
         # Predicate operations
         if "_eq" in value:
-            combined_qs.append(Q(**{key: get_raw_value(value["_eq"])}))
+            anded_qs.append(Q(**{key: get_raw_value(value["_eq"])}))
         if "_neq" in value:
-            combined_qs.append(~Q(**{key: get_raw_value(value["_neq"])}))
+            anded_qs.append(~Q(**{key: get_raw_value(value["_neq"])}))
         if "_gt" in value:
-            combined_qs.append(Q(**{"{}__gt".format(key): get_raw_value(value["_gt"])}))
+            anded_qs.append(Q(**{"{}__gt".format(key): get_raw_value(value["_gt"])}))
         if "_gte" in value:
-            combined_qs.append(
+            anded_qs.append(
                 Q(**{"{}__gte".format(key): get_raw_value(value["_gte"])})
             )
         if "_lt" in value:
-            combined_qs.append(Q(**{"{}__lt".format(key): get_raw_value(value["_lt"])}))
+            anded_qs.append(Q(**{"{}__lt".format(key): get_raw_value(value["_lt"])}))
         if "_lte" in value:
-            combined_qs.append(
+            anded_qs.append(
                 Q(**{"{}__lte".format(key): get_raw_value(value["_lte"])})
             )
         if "_in" in value:
-            combined_qs.append(Q(**{"{}__in".format(key): get_raw_value(value["_in"])}))
+            anded_qs.append(Q(**{"{}__in".format(key): get_raw_value(value["_in"])}))
         if "_nin" in value:
-            combined_qs.append(
+            anded_qs.append(
                 ~Q(**{"{}__in".format(key): get_raw_value(value["_nin"])})
             )
         if "_is_null" in value:
-            combined_qs.append(
+            anded_qs.append(
                 Q(**{"{}__isnull".format(key): get_raw_value(value["_is_null"])})
             )
         if "_like" in value:
-            combined_qs.append(
+            anded_qs.append(
                 Q(**{"{}__contains".format(key): get_raw_value(value["_like"])})
             )
         if "_ilike" in value:
             annotations["{}_lower".format(key)] = Lower(key)
-            combined_qs.append(
+            anded_qs.append(
                 Q(
                     **{
                         "{}_lower__icontains".format(key): get_raw_value(
@@ -112,15 +113,17 @@ def filter_from_where_args(where_args, annotations, _and=True):
                 )
             )
 
-    if not combined_qs:
-        # If we're here, the where clause contains a nested join, e.g.
-        # albums(where: { artist: { label: { name: {_eq: "Record Co."}}}})
-        # which means we need to generate Q(artist__label__name='Record Co.')
-        for next_key, next_value in iteritems(value):
-            nested_key = "{}__{}".format(key, next_key)
-            combined_qs.append(
-                filter_from_where_args({nested_key: next_value}, annotations)
-            )
+        if not anded_qs:
+            # If we're here, the where clause contains a nested join, e.g.
+            # albums(where: { artist: { label: { name: {_eq: "Record Co."}}}})
+            # which means we need to generate Q(artist__label__name='Record Co.')
+            for next_key, next_value in iteritems(value):
+                nested_key = f"{key}__{next_key}"
+                anded_qs.append(
+                    filter_from_where_args({nested_key: next_value}, annotations)
+                )
+
+        combined_qs.extend(anded_qs)
 
     if not combined_qs:
         print("Warning: combined_qs should never be empty at this point.")
