@@ -3,6 +3,13 @@ from .query_fields_visitor import QueryFieldsVisitor
 
 class ReadPermissionsCheckVisitor(QueryFieldsVisitor):
     def hello_field(self, field, arguments, graphql_node=None):
+        # Edge case: If a ComputedField defines a depends_on list and returns
+        # a non-djraphql-generated type, then field.related_model here will be
+        # None, in which case we just allow reading it, because the parent
+        # entity already passed the check.
+        if field.related_model is None:
+            return
+
         # If this is the "fooId" field (vs. the "foo" field), then
         # it's perfectly fine to read, because it's a scalar field
         # on a type that's already passed permissions-check successfully.
